==> aws-java-sdk-datapipeline-1.11.39-sources.jar: com/amazonaws/services/datapipeline/model/transform/ValidationWarningJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.datapipeline.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.datapipeline.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ValidationWarningMarshaller
 */
public class ValidationWarningJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(ValidationWarning validationWarning, StructuredJsonGenerator jsonGenerator) {

        if (validationWarning == null) {
            throw new AmazonClientException("Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (validationWarning.getId() != null) {
                jsonGenerator.writeFieldName("id").writeValue(validationWarning.getId());
            }

            com.amazonaws.internal.SdkInternalList<String> warningsList = (com.amazonaws.internal.SdkInternalList<String>) validationWarning.getWarnings();
            if (!warningsList.isEmpty() || !warningsList.isAutoConstruct()) {
                jsonGenerator.writeFieldName("warnings");
                jsonGenerator.writeStartArray();
                for (String warningsListValue : warningsList) {
                    if (warningsListValue != null) {
                        jsonGenerator.writeValue(warningsListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ValidationWarningJsonMarshaller instance;

    public static ValidationWarningJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ValidationWarningJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-datapipeline-1.11.54-sources.jar: com/amazonaws/services/datapipeline/model/transform/ValidationWarningJsonMarshaller.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package com.amazonaws.services.datapipeline.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.SdkClientException;
import com.amazonaws.services.datapipeline.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.protocol.json.*;

/**
 * ValidationWarningMarshaller
 */
public class ValidationWarningJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(ValidationWarning validationWarning, StructuredJsonGenerator jsonGenerator) {

        if (validationWarning == null) {
            throw new SdkClientException("Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (validationWarning.getId() != null) {
                jsonGenerator.writeFieldName("id").writeValue(validationWarning.getId());
            }

            com.amazonaws.internal.SdkInternalList<String> warningsList = (com.amazonaws.internal.SdkInternalList<String>) validationWarning.getWarnings();
            if (!warningsList.isEmpty() || !warningsList.isAutoConstruct()) {
                jsonGenerator.writeFieldName("warnings");
                jsonGenerator.writeStartArray();
                for (String warningsListValue : warningsList) {
                    if (warningsListValue != null) {
                        jsonGenerator.writeValue(warningsListValue);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new SdkClientException("Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static ValidationWarningJsonMarshaller instance;

    public static ValidationWarningJsonMarshaller getInstance() {
        if (instance == null)
            instance = new ValidationWarningJsonMarshaller();
        return instance;
    }

}
